HISTORY
--------

## 1.4 (2020-8-8)
- Add the `--keep-prints` option for keeping print nodes, default is False. (By @thektulu)
- Add the `--module-level` option for module level diff, default is False. (By @thektulu)

## 1.3 (2019-12-8)
- Fix python 3.8 compatibility issue [#4](https://github.com/fyrestone/pycode_similar/issues/4) (Thanks to aginiewicz)
- Remove import expr

## 1.2 (2018-1-18)

- Fix python3 compatibility issue.
- Remove print for python23.

## 1.1 (2017-10-04)

- Add TreeDiff method based on zss.
- Fixed sub nodes of Expr are not normalized.
- Fixed incorrect result when detect target contains no function.

## 1.0 (2017-10-01)

- Init
